@@ -7,10 +7,16 @@
 __docformat__ = "restructuredtext en"
 
 from cubicweb.entities import AnyEntity, fetch_config
-from cubicweb.mixins import TreeMixIn
+from cubicweb.entities.adapters import ITreeAdapter
+from cubicweb.selectors import is_instance
 
-class Zone(TreeMixIn, AnyEntity):
+class Zone(AnyEntity):
     """customized class for Zone entities"""
     __regid__ = 'Zone'
     fetch_attrs, fetch_order = fetch_config(['name'])
-    tree_attribute = 'situated_in'
+
+
+class ZoneITreeAdapter(ITreeAdapter):
+    __select__ = is_instance('Zone')
+    tree_relation = 'situated_in'
+
